<?php
/*
 * 1. Récupérer les données
 * 2. Effectuer les contrôles
 * 3. Si KO → 
 *     3.1 : stocker les erreurs en variables de session
 *     3.2 : rediriger vers le formulaire
 * 4. Si OK → 
 *     4.1 : Enregistrer en base de données
 *     4.2 : Identifier l'utilisateur
 *     4.2 : Rediriger l'internaute
 */
include('init.php');

/* 
 * 1. récupération des données saisies (et mise en session)
 */
foreach($_POST as $key => $value) {
  $$key = htmlentities($value);
  $_SESSION[$key] = $value;
}

/*
 * 2. Contrôles
 */
unset($_SESSION['erreur']);
$error = [];

// Contrôles de surface
if ( empty($pseudo) ) {       $error['pseudo']       = 'Veuillez choisir un pseudo.'; }
if ( empty($pass) ) {         $error['pass']         = 'Veuillez choisir un mot de passe.'; }
if ( empty($pass_confirm) ) { $error['pass_confirm'] = 'Veuillez confirmer le mot de passe.'; }
if ( empty($email) ) {        $error['email']        = 'Veuillez fournir une adresse e-mail.'; }
if ( !empty( $error ) ) {
  $_SESSION['erreur'] = $error;
  header('Location: ../inscription.php');
  exit();
}

// Contrôles de cohérence
if( $pass != $pass_confirm ) { 
  $error['pass_confirm'] = 'Le mot de passe et sa confirmation ne correspondent pas.'; 
}
if ( !preg_match("/([\w\-]+\@[\w\-]+\.[\w\-]+)/", $email) ) { 
  $error['email'] = 'L\'adresse email indiquée ne semble pas conforme, merci de vérifier qu\'elle est bien de la forme "exemple@domaine.com".';
}
if ( !empty( $error ) ) {
  $_SESSION['erreur'] = $error;
  header('Location: ../inscription.php');
  exit();
}

// Contrôles d'unicité du membre (e-mail)
$sql = "SELECT * FROM `membres` WHERE `email` = :email";
$pdoStatement = $conn->prepare($sql);
$pdoStatement->bindParam(':email', $email, PDO::PARAM_STR);
$res = $pdoStatement->execute();
if ( $res ) {
  $result = $pdoStatement->fetchAll();
  if ( count( $result ) > 0 ) {
    $error['email'] = 'Cet email est déjà pris. Si c\'est vous, vous pouvez <a href="identification.php">vous identifier</a>. Sinon veuillez en choisir un autre.';
  }
}
// Contrôles d'unicité du membre (pseudo)
$sql = "SELECT * FROM `membres` WHERE `pseudo` = :pseudo";
$pdoStatement = $conn->prepare($sql);
$pdoStatement->bindParam(':pseudo', $pseudo, PDO::PARAM_STR);
$res = $pdoStatement->execute();
if ( $res ) {
  $result = $pdoStatement->fetchAll();
  if ( count( $result ) > 0 ) {
    $error['pseudo'] = 'Cet identifiant est déjà pris. Si c\'est vous, vous pouvez <a href="identification.php">vous identifier</a>. Sinon veuillez en choisir un autre.';
  }
}
if ( !empty( $error ) ) {
  $_SESSION['erreur'] = $error;
  header('Location: ../inscription.php');
  exit();
}

// Si tous les contrôles sont ok, on insère l'utilisateur dans notre base de données
$sql = "INSERT INTO `membres` (`pseudo`, `email`, `pass`, `date`) VALUES (:pseudo, :email, :pass, NOW())";
$pdoStatement = $conn->prepare($sql);
$encrypted_pass = password_hash($pass, PASSWORD_DEFAULT);
$pdoStatement->bindParam(':pseudo', $pseudo, PDO::PARAM_STR);
$pdoStatement->bindParam(':email', $email, PDO::PARAM_STR);
$pdoStatement->bindParam(':pass', $encrypted_pass, PDO::PARAM_STR);
$pdoStatement->execute();

// puis on l'identifie, pour qu'il n'ai pas à le faire via le formulaire d'identification
$_SESSION['pseudoUtilisateur'] = $pseudo;
$_SESSION['passwordUtilisateur'] = $encrypted_pass;

// on efface les données de session liées à la saisie de l'internaute
foreach($_POST as $key => $value) {
  unset($_SESSION[$key]);
}
unset($_SESSION['erreur']);

// enfin on le redirige vers un message de succès
header('Location: ../succes.php');
exit;